#!/bin/bash

#This script is to tokenize bcl application on MAC and linux.
#and uploads to the device if ip address is provided.

OS_PLT=`uname | tr '[A-Z]' '[a-z]'| grep -o darwin`       # on MAC OS it is "darwin"

if [ "${OS_PLT}" = "" ]; then
    OS_PLT=`uname | tr '[A-Z]' '[a-z]'| grep -o linux`
fi

if [ "${OS_PLT}" = "" ]; then
	OS_PLT=`uname | tr '[A-Z]' '[a-z]'| grep -o cygwin`
fi
if [ "${OS_PLT}" = "" ]; then
    echo "Platform `uname` is not supported"
    exit -1
fi

if [ $# -lt 1 ] ; then echo -e "BCL devkit tool, (c)2006 Barix AG\nUsage: $0 <project_name> [<ip_address>]\n" ; exit 0 ; fi


function translate {
cat $1 | $crlf_path
}

CPCRLF=../tools/cpcrlf
if [ "${OS_PLT}" = "linux" ]; then
#linux
TFTP=atftp
BPKG=../tools/bpkg-static-linux-x86
TOKENIZER=../../tools/tokenizer-static-linux-x86
fi

if [ "${OS_PLT}" = "darwin" ]; then
#mac
TFTP=../tools/atftp-mac-emul
BPKG=../tools/bpkg-mac-x86
TOKENIZER=../../tools/tokenizer-mac-x86
else
echo "assume cygwin"
TFTP=atftp
BPKG=../tools/web2cob
TOKENIZER=../../tools/tokenizer
fi

old_path=`pwd`
to_path=`dirname "$0"`
cd "${to_path}"

echo "current path: $(pwd)"

DESTINATION_PAGE=WEB4

${CPCRLF} -r $1 bla

IS_BCL=0
BAS_FILE="$1.bas"
# .BCL support
if [ -f $1/$1.bcl ] ; then
   mkdir bla/BCL
   # there could be multiple .bcl's
   for module in $(ls $1/*.bcl);
   do
      ${CPCRLF} ${module} bla/BCL
   done
   # no double code
   rm bla/*.bcl
   BAS_FILE="$1.bcl"
   IS_BCL=1
else
 if ! [ -f $1/$1.bas ] ; then
   #check if there us any bas file.
   bas_count=0
   if ! [ -d $1 ]; then
     exit 1 
   fi

   cd $1
   mod_count=`ls *.bas | wc -l`
   if [ "$mod_count" -eq "1" ]; then
       BAS_FILE=`ls *.bas`
   else
      if [ "$mod_count" -gt "1" ]; then
          echo "Many BAS files found in folder $1"
          echo "When $1.bas  file not present, make sure that you have only one BAS file in $1 folder"
          exit 3
      else
          echo "No BAS file found for tokenization"
          exit 3
      fi
   fi
   cd ..
 fi
fi

echo "# Tokenizing application \"$1\""
cd bla
if ${TOKENIZER} barionet100 ${BAS_FILE} ; then : ; else echo "ERROR - TOKENIZER REPORTS FAILURE" ; fi
cd ../

rm -f bla/*.bak bla/*.BAK

if [ "$IS_BCL" = "1" ] ; then
	rm -f bla/$1.bas bla/$1.BAS
fi

echo "# Creating cob file"
${BPKG} /o $1.cob /d bla
rm -rf bla
echo
if [ $# -gt 1 ] ; then
	echo "# Uploading to barionet ..."
	${TFTP} -l $1.cob -r ${DESTINATION_PAGE} -p $2
fi

cd "${old_path}"


